==> jc-1.4.0.tar.gz: java/awt/EventDispatchThread.h <==
// class java.awt.EventDispatchThread

// class file dependencies
// @dep_class cecfd8b6e2dc27d5 java_awt_EventDispatchThread
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_java_awt_EventDispatchThread_H_
#define _JC_java_awt_EventDispatchThread_H_

// Forward structure declarations
struct _jc_java_awt_EventQueue$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_EventDispatchThread$sub_refs	_jc_java_awt_EventDispatchThread$sub_refs;
typedef struct _jc_java_awt_EventDispatchThread$sub_nonrefs	_jc_java_awt_EventDispatchThread$sub_nonrefs;
typedef struct _jc_java_awt_EventDispatchThread$refs	_jc_java_awt_EventDispatchThread$refs;
typedef struct _jc_java_awt_EventDispatchThread$nonrefs	_jc_java_awt_EventDispatchThread$nonrefs;
typedef struct _jc_java_awt_EventDispatchThread$object	_jc_java_awt_EventDispatchThread$object;

typedef struct _jc_java_awt_EventDispatchThread$fields_struct	_jc_java_awt_EventDispatchThread$fields_struct;
typedef const struct _jc_java_awt_EventDispatchThread$vmethods	_jc_java_awt_EventDispatchThread$vmethods;
typedef const struct _jc_java_awt_EventDispatchThread$vtable	_jc_java_awt_EventDispatchThread$vtable;
typedef const struct _jc_java_awt_EventDispatchThread$vtype	_jc_java_awt_EventDispatchThread$vtype;

// Class fields structure
struct _jc_java_awt_EventDispatchThread$fields_struct {
	jint	dispatchThreadNum;
};
extern _jc_java_awt_EventDispatchThread$fields_struct _jc_java_awt_EventDispatchThread$class_fields;

// Constructors
extern void _jc_java_awt_EventDispatchThread$method$_init$277e9f0e1e366bbc(_jc_env *, struct _jc_java_awt_EventDispatchThread$object *, struct _jc_java_awt_EventQueue$object *);

// Virtual methods
extern void _jc_java_awt_EventDispatchThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_awt_EventDispatchThread$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_EventDispatchThread$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_java_awt_EventDispatchThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_awt_EventDispatchThread$object *);
};

// Vtable
struct _jc_java_awt_EventDispatchThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_java_awt_EventDispatchThread$vmethods	java_awt_EventDispatchThread;
};

// Vtype
struct _jc_java_awt_EventDispatchThread$vtype {
	_jc_type			type;
	_jc_java_awt_EventDispatchThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_EventDispatchThread$sub_refs {
	struct _jc_java_awt_EventQueue$object	*queue;
};

// Reference instance fields (object)
struct _jc_java_awt_EventDispatchThread$refs {
    _jc_java_awt_EventDispatchThread$sub_refs	java_awt_EventDispatchThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_EventDispatchThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_EventDispatchThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_java_awt_EventDispatchThread$sub_nonrefs	java_awt_EventDispatchThread;
};

// Object instance structure
struct _jc_java_awt_EventDispatchThread$object {
	_jc_java_awt_EventDispatchThread$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_EventDispatchThread$vtype	*vtype;
	_jc_java_awt_EventDispatchThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_EventDispatchThread$vtype _jc_java_awt_EventDispatchThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_EventDispatchThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_EventDispatchThread$class_object;

#endif	/* _JC_java_awt_EventDispatchThread_H_ */

==> jc-1.4.6.tar.gz: java/awt/EventDispatchThread.h <==
// class java.awt.EventDispatchThread

// class file dependencies
// @dep_class cecfd8b6e2dc27d5 java_awt_EventDispatchThread
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_java_awt_EventDispatchThread_H_
#define _JC_java_awt_EventDispatchThread_H_

// Forward structure declarations
struct _jc_java_awt_EventQueue$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_EventDispatchThread$sub_refs	_jc_java_awt_EventDispatchThread$sub_refs;
typedef struct _jc_java_awt_EventDispatchThread$sub_nonrefs	_jc_java_awt_EventDispatchThread$sub_nonrefs;
typedef struct _jc_java_awt_EventDispatchThread$refs	_jc_java_awt_EventDispatchThread$refs;
typedef struct _jc_java_awt_EventDispatchThread$nonrefs	_jc_java_awt_EventDispatchThread$nonrefs;
typedef struct _jc_java_awt_EventDispatchThread$object	_jc_java_awt_EventDispatchThread$object;

typedef struct _jc_java_awt_EventDispatchThread$fields_struct	_jc_java_awt_EventDispatchThread$fields_struct;
typedef const struct _jc_java_awt_EventDispatchThread$vmethods	_jc_java_awt_EventDispatchThread$vmethods;
typedef const struct _jc_java_awt_EventDispatchThread$vtable	_jc_java_awt_EventDispatchThread$vtable;
typedef const struct _jc_java_awt_EventDispatchThread$vtype	_jc_java_awt_EventDispatchThread$vtype;

// Class fields structure
struct _jc_java_awt_EventDispatchThread$fields_struct {
	jint	dispatchThreadNum;
};
extern _jc_java_awt_EventDispatchThread$fields_struct _jc_java_awt_EventDispatchThread$class_fields;

// Constructors
extern void _jc_java_awt_EventDispatchThread$method$_init$277e9f0e1e366bbc(_jc_env *, struct _jc_java_awt_EventDispatchThread$object *, struct _jc_java_awt_EventQueue$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_EventDispatchThread$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_awt_EventDispatchThread$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_EventDispatchThread$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_java_awt_EventDispatchThread$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_awt_EventDispatchThread$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_EventDispatchThread$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_java_awt_EventDispatchThread$vmethods	java_awt_EventDispatchThread;
};

// Vtype
struct _jc_java_awt_EventDispatchThread$vtype {
	_jc_type			type;
	_jc_java_awt_EventDispatchThread$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_EventDispatchThread$sub_refs {
	struct _jc_java_awt_EventQueue$object	*queue;
};

// Reference instance fields (object)
struct _jc_java_awt_EventDispatchThread$refs {
    _jc_java_awt_EventDispatchThread$sub_refs	java_awt_EventDispatchThread;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_EventDispatchThread$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_EventDispatchThread$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_java_awt_EventDispatchThread$sub_nonrefs	java_awt_EventDispatchThread;
};

// Object instance structure
struct _jc_java_awt_EventDispatchThread$object {
	_jc_java_awt_EventDispatchThread$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_EventDispatchThread$vtype	*vtype;
	_jc_java_awt_EventDispatchThread$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_EventDispatchThread$vtype _jc_java_awt_EventDispatchThread$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_EventDispatchThread, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_EventDispatchThread$class_object;

#endif	/* _JC_java_awt_EventDispatchThread_H_ */
